@@ -1,5 +1,6 @@
 import datetime
 import functools
+import io
 import typing
 from unittest.mock import MagicMock
 
@@ -77,6 +78,18 @@ class Client:
         request = _validation.validate_input(method, args, kwargs)
         response = _casting.cast(method.output, raw)
 
+        # The s3.download_fileobj is a special case where the data is written to the
+        # FileObj argument and not returned via an output argument.
+        if self._service_name == "s3" and called_method_name == "download_fileobj":
+            buffer: io.BytesIO = request["FileObj"]
+            file_obj_data: typing.Union[str, bytes, None] = response.pop(
+                "FileObj", None
+            )
+            if isinstance(file_obj_data, str):
+                file_obj_data = file_obj_data.encode()
+            if file_obj_data:
+                buffer.write(file_obj_data)
+
         service_call = lobotomy.ServiceCall(
             service=self._service_name,
             method=called_method_name,
